@@ -1,12 +1,11 @@
 import logging
 from os.path import dirname
-from syncloud.tools import logger
+from syncloud.app import logger
 from syncloud.tools.cpu.cpuinfo import CpuInfo
 from syncloud.tools.cpu.reader import Reader
 
 test_dir = dirname(__file__)
-logger.console = True
-logger.level = logging.DEBUG
+logger.init(logging.DEBUG, console=True)
 
 
 def test_hardware():
